@@ -247,11 +247,84 @@ randomOrthogonalMatrix <- function(nrow, ncol, n = nrow, d = ncol, seed = NULL)
   return(Q)
 }
 
-logsumexp <- function(x)
-{ 
-# Numerically efficient implementation of log(sum(exp(x)))
-  max <- max(x)
-  max + log(sum(exp(x-max)))
+# TODO: to be removed at a certain point
+# logsumexp_old <- function(x)
+# { 
+# # Numerically efficient implementation of log(sum(exp(x)))
+#   max <- max(x)
+#   max + log(sum(exp(x-max)))
+# }
+
+logsumexp <- function(x, v = NULL)
+{
+# Numerically efficient implementation of 
+#   log-sum-exp(x_i+v)  for i = 1,...,n
+# via Fortran call
+  x <- if(is.null(dim(x))) matrix(x, nrow = 1) else as.matrix(x)
+  n <- nrow(x)
+  k <- ncol(x)
+  v <- if(is.null(v)) double(k) else as.vector(v)
+  stopifnot(length(v) == k)
+  .Fortran("logsumexp", 
+           x = x, 
+           n = as.integer(n), 
+           k = as.integer(k), 
+           v = v, 
+           lse = double(n),
+           PACKAGE = "mclust")$lse
+}
+
+softmax <- function(x, v = NULL)
+{
+# Efficiently computes softmax function based on 
+#   log-sum-exp(x_i+v) for i = 1,...,n
+# via Fortran call such that the output matrix z (n x k) has 
+# rowsum(z_j) = 1 for j = 1,...,k
+# 
+  x <- if(is.null(dim(x))) matrix(x, nrow = 1) else as.matrix(x)
+  n <- nrow(x)
+  k <- ncol(x)
+  v <- if(is.null(v)) double(k) else as.vector(v)
+  stopifnot(length(v) == k)
+  
+  z <- .Fortran("softmax", 
+                x = x, 
+                n = as.integer(n), 
+                k = as.integer(k), 
+                v = as.double(v), 
+                lse = double(n), 
+                z = double(n * k),
+                PACKAGE = "mclust")$z
+  z <- matrix(z, nrow = n, ncol = k)
+  return(z)
+}
+
+count <- function(x, bins)
+{
+# Return the counts for each values equal to bins via 
+# numerically efficient Fortran code.
+# 
+# Example:
+# x = c(1, 2, 4, 2, 5, 3, 2, 1, 6, 5, 3, 4, 4, 2, 1)
+# count(x, bins = 0:10)
+# 
+  x <- as.vector(x)
+  if(!is.numeric(x))
+    x <- as.factor(x)
+  n <- length(x)
+  bins <- as.vector(bins)
+  if(!is.numeric(bins))
+    bins <- as.factor(bins)
+  m <- length(bins)
+  freq <- .Fortran("countf", 
+                   x = as.integer(x), 
+                   n = as.integer(n), 
+                   bins = as.integer(bins), 
+                   m = as.integer(m), 
+                   freq = integer(m),
+                   PACKAGE = "mclust")[[5]]
+  names(freq) <- as.character(bins)
+  return(freq)
 }
 
 partconv <- function(x, consec = TRUE)
@@ -499,6 +572,27 @@ hdrlevels <- function(density, prob)
   return(lev)
 }
 
+nclass.numpy <- function(x, ...)
+{
+#' Compute the number of classes for a histogram as the maximum of the 
+#' "Sturges" and "FD" (Freedman Diaconis) estimators as in numpy library
+#' for Python. 
+#' x: a vector of values
+#'
+#' Example:
+#' x <- rnorm(100)
+#' hist(x, breaks = nclass.numpy(x))
+#' x <- rnorm(1000)
+#' hist(x, breaks = nclass.numpy(x))
+#' n = c(50, seq(100,1000,by=100))
+#' brks = rep(NA, length(n))
+#' for(i in seq(n)) brks[i] = nclass.numpy(rnorm(n[i]))
+#' plot(n, brks)
+#' 
+  x <- as.vector(x)
+  max(nclass.Sturges(x), nclass.FD(x))
+}
+
 catwrap <- function(x, width = getOption("width"), ...)
 {
 # version of cat with wrapping at specified width
